@@ -5,6 +5,7 @@ function(xdata,n.ahead,p,d,q,P=0,D=0,Q=0,S=-1,tol=sqrt(.Machine$double.eps),no.c
    par = graphics::par
    plot = graphics::plot
    grid = graphics::grid
+   box = graphics::box
    abline = graphics::abline
    lines = graphics::lines
    frequency = stats::frequency
@@ -33,8 +34,10 @@ function(xdata,n.ahead,p,d,q,P=0,D=0,Q=0,S=-1,tol=sqrt(.Machine$double.eps),no.c
 #--
  fore=stats::predict(fitit, n.ahead, newxreg=nureg)  
 #-- graph:
-  U = fore$pred + 2*fore$se
-  L = fore$pred - 2*fore$se
+  U  = fore$pred + 2*fore$se
+  L  = fore$pred - 2*fore$se
+  U1 = fore$pred + fore$se
+  L1 = fore$pred - fore$se
    a=max(1,n-100)
   minx=min(xdata[a:n],L)
   maxx=max(xdata[a:n],U)
@@ -43,13 +46,19 @@ function(xdata,n.ahead,p,d,q,P=0,D=0,Q=0,S=-1,tol=sqrt(.Machine$double.eps),no.c
    t2=xy.coords(fore$pred, y = NULL)$x 
    endd=t2[length(t2)]
    xllim=c(strt,endd)
+  par(mar=c(2.5, 2.5, 1, 1), mgp=c(1.6,.6,0))
   ts.plot(xdata,fore$pred, type="n", xlim=xllim, ylim=c(minx,maxx), ylab=xname) 
-  grid(lty=1, col=gray(.9))
+  grid(lty=1, col=gray(.9)); box()
   lines(xdata, type='o')
-  lines(fore$pred, col="red", type="o")
-  lines(U, col="blue", lty="dashed")
-  lines(L, col="blue", lty="dashed") 
-#
+#  
+   xx = c(time(U), rev(time(U)))
+   yy = c(L, rev(U))
+   polygon(xx, yy, border=8, col=gray(.6, alpha=.2) ) 
+   yy1 = c(L1, rev(U1))
+   polygon(xx, yy1, border=8, col=gray(.6, alpha=.2) ) 
+   
+   lines(fore$pred, col="red", type="o")
   return(fore)
 }
 
+
